@@ -4,8 +4,10 @@ from typing import overload
 import numpy as np
 import pandas as pd
 
-type ScalarDateTypes = str | np.datetime64 | pd.Timestamp | dt.datetime | dt.date
-type ArrayDateTypes = pd.Series | pd.DatetimeIndex | np.ndarray | list | tuple
+DateScalar = str | np.datetime64 | pd.Timestamp | dt.datetime | dt.date
+DateArray = (
+    pd.Series | pd.DatetimeIndex | np.ndarray | list[DateScalar] | tuple[DateScalar]
+)
 
 
 def validate_date_format(date_str):
@@ -22,18 +24,21 @@ def validate_date_format(date_str):
 
 
 @overload
-def convert_input_dates(dates: ScalarDateTypes) -> pd.Timestamp: ...
+def convert_input_dates(dates: DateScalar) -> pd.Timestamp: ...
 @overload
-def convert_input_dates(dates: ArrayDateTypes) -> pd.Series: ...
+def convert_input_dates(dates: DateArray) -> pd.Series: ...
 
 
 def convert_input_dates(
-    dates: ScalarDateTypes | ArrayDateTypes,
+    dates: DateScalar | DateArray,
 ) -> pd.Timestamp | pd.Series:
-    match dates:
-        case None:
-            raise ValueError("'dates' cannot be None.")
+    # Capturar apenas escalares nulos: a verificação `is True` é crucial,
+    # pois `pd.isna()` retorna um array booleano para entradas de array,
+    # e um array nunca é idêntico ao objeto singleton `True`.
+    if pd.isna(dates) is True:
+        return pd.NaT
 
+    match dates:
         case str():
             validate_date_format(dates)
             return pd.to_datetime(dates, dayfirst=True)
@@ -42,6 +47,7 @@ def convert_input_dates(
             return pd.Timestamp(dates).normalize()
 
         case pd.Series() | np.ndarray() | list() | tuple():
+            # Preserve input values making a copy
             result = pd.Series(dates)
 
             if result.empty:
@@ -49,7 +55,7 @@ def convert_input_dates(
 
             if pd.api.types.is_string_dtype(result):
                 # Check first element to validate date format
-                validate_date_format(result[0])
+                validate_date_format(result.iloc[0])
 
             return pd.to_datetime(result, dayfirst=True).astype("datetime64[ns]")
 
@@ -72,7 +78,9 @@ def to_numpy_date_type(
     Returns:
         np.datetime64 | np.ndarray: The input dates in a numpy datetime64[D] format.
     """
-    if isinstance(dates, pd.Timestamp):
+    if pd.isna(dates) is True:
+        return np.datetime64("NaT")
+    elif isinstance(dates, pd.Timestamp) or dates is pd.NaT:
         return np.datetime64(dates, "D")
     elif isinstance(dates, pd.Series):
         return dates.to_numpy().astype("datetime64[D]")
